==> open-cluster-management-search-model-6.5.1-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchCustomizationFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SearchCustomizationFluentImpl<A extends SearchCustomizationFluent<A>> extends BaseFluent<A> implements SearchCustomizationFluent<A>{
  public SearchCustomizationFluentImpl() {
  }
  public SearchCustomizationFluentImpl(SearchCustomization instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SearchCustomizationSpecBuilder spec;
  private SearchCustomizationStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SearchCustomizationFluent.MetadataNested<A> withNewMetadata() {
    return new SearchCustomizationFluentImpl.MetadataNestedImpl();
  }
  public SearchCustomizationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SearchCustomizationFluentImpl.MetadataNestedImpl(item);
  }
  public SearchCustomizationFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SearchCustomizationFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SearchCustomizationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SearchCustomizationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SearchCustomizationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SearchCustomizationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SearchCustomizationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public A withNewSpec(Boolean persistence,String storageClass,String storageSize) {
    return (A)withSpec(new SearchCustomizationSpec(persistence, storageClass, storageSize));
  }
  public SearchCustomizationFluent.SpecNested<A> withNewSpec() {
    return new SearchCustomizationFluentImpl.SpecNestedImpl();
  }
  public SearchCustomizationFluent.SpecNested<A> withNewSpecLike(SearchCustomizationSpec item) {
    return new SearchCustomizationFluentImpl.SpecNestedImpl(item);
  }
  public SearchCustomizationFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SearchCustomizationFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SearchCustomizationSpecBuilder().build());
  }
  public SearchCustomizationFluent.SpecNested<A> editOrNewSpecLike(SearchCustomizationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SearchCustomizationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SearchCustomizationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SearchCustomizationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SearchCustomizationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean persistence,String storageClass,String storageSize) {
    return (A)withStatus(new SearchCustomizationStatus(persistence, storageClass, storageSize));
  }
  public SearchCustomizationFluent.StatusNested<A> withNewStatus() {
    return new SearchCustomizationFluentImpl.StatusNestedImpl();
  }
  public SearchCustomizationFluent.StatusNested<A> withNewStatusLike(SearchCustomizationStatus item) {
    return new SearchCustomizationFluentImpl.StatusNestedImpl(item);
  }
  public SearchCustomizationFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SearchCustomizationFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SearchCustomizationStatusBuilder().build());
  }
  public SearchCustomizationFluent.StatusNested<A> editOrNewStatusLike(SearchCustomizationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SearchCustomizationFluentImpl that = (SearchCustomizationFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SearchCustomizationFluent.MetadataNested<N>> implements SearchCustomizationFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SearchCustomizationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SearchCustomizationSpecFluentImpl<SearchCustomizationFluent.SpecNested<N>> implements SearchCustomizationFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SearchCustomizationSpec item) {
      this.builder = new SearchCustomizationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SearchCustomizationSpecBuilder(this);
    }
    SearchCustomizationSpecBuilder builder;
    public N and() {
      return (N) SearchCustomizationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SearchCustomizationStatusFluentImpl<SearchCustomizationFluent.StatusNested<N>> implements SearchCustomizationFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SearchCustomizationStatus item) {
      this.builder = new SearchCustomizationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SearchCustomizationStatusBuilder(this);
    }
    SearchCustomizationStatusBuilder builder;
    public N and() {
      return (N) SearchCustomizationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-search-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchCustomizationFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SearchCustomizationFluentImpl<A extends SearchCustomizationFluent<A>> extends BaseFluent<A> implements SearchCustomizationFluent<A>{
  public SearchCustomizationFluentImpl() {
  }
  public SearchCustomizationFluentImpl(SearchCustomization instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SearchCustomizationSpecBuilder spec;
  private SearchCustomizationStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SearchCustomizationFluentImpl.MetadataNested<A> withNewMetadata() {
    return new SearchCustomizationFluentImpl.MetadataNestedImpl();
  }
  public SearchCustomizationFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SearchCustomizationFluentImpl.MetadataNestedImpl(item);
  }
  public SearchCustomizationFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SearchCustomizationFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SearchCustomizationFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SearchCustomizationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SearchCustomizationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SearchCustomizationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SearchCustomizationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public A withNewSpec(Boolean persistence,String storageClass,String storageSize) {
    return (A)withSpec(new SearchCustomizationSpec(persistence, storageClass, storageSize));
  }
  public SearchCustomizationFluentImpl.SpecNested<A> withNewSpec() {
    return new SearchCustomizationFluentImpl.SpecNestedImpl();
  }
  public SearchCustomizationFluentImpl.SpecNested<A> withNewSpecLike(SearchCustomizationSpec item) {
    return new SearchCustomizationFluentImpl.SpecNestedImpl(item);
  }
  public SearchCustomizationFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SearchCustomizationFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SearchCustomizationSpecBuilder().build());
  }
  public SearchCustomizationFluentImpl.SpecNested<A> editOrNewSpecLike(SearchCustomizationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SearchCustomizationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SearchCustomizationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SearchCustomizationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SearchCustomizationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean persistence,String storageClass,String storageSize) {
    return (A)withStatus(new SearchCustomizationStatus(persistence, storageClass, storageSize));
  }
  public SearchCustomizationFluentImpl.StatusNested<A> withNewStatus() {
    return new SearchCustomizationFluentImpl.StatusNestedImpl();
  }
  public SearchCustomizationFluentImpl.StatusNested<A> withNewStatusLike(SearchCustomizationStatus item) {
    return new SearchCustomizationFluentImpl.StatusNestedImpl(item);
  }
  public SearchCustomizationFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SearchCustomizationFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SearchCustomizationStatusBuilder().build());
  }
  public SearchCustomizationFluentImpl.StatusNested<A> editOrNewStatusLike(SearchCustomizationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SearchCustomizationFluentImpl that = (SearchCustomizationFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SearchCustomizationFluentImpl.MetadataNested<N>> implements SearchCustomizationFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SearchCustomizationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SearchCustomizationSpecFluentImpl<SearchCustomizationFluentImpl.SpecNested<N>> implements SearchCustomizationFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SearchCustomizationSpec item) {
      this.builder = new SearchCustomizationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SearchCustomizationSpecBuilder(this);
    }
    SearchCustomizationSpecBuilder builder;
    public N and() {
      return (N) SearchCustomizationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SearchCustomizationStatusFluentImpl<SearchCustomizationFluentImpl.StatusNested<N>> implements SearchCustomizationFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SearchCustomizationStatus item) {
      this.builder = new SearchCustomizationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SearchCustomizationStatusBuilder(this);
    }
    SearchCustomizationStatusBuilder builder;
    public N and() {
      return (N) SearchCustomizationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
